==> core-react-0.8.0.tgz: package/es/Modal/Modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import classlist from 'classlist';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import EventPool from '../_utils/EventPool';
import ToggleNode from '../_utils/ToggleNode';
import ModalContent from './ModalContent';

var scrollbarWidth = function () {
  var scrollDiv = document.createElement('div');
  var body = document.body;
  scrollDiv.className = "".concat("waui", "-modal__scrollbar-measure");
  body.appendChild(scrollDiv);
  var scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
  body.removeChild(scrollDiv);
  return scrollbarWidth;
}();

var Modal = /*#__PURE__*/function (_Component) {
  _inherits(Modal, _Component);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Modal).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _this.props.onClose;

      _this.setState({
        open: false
      });

      _this.props.onToggle && _this.props.onToggle(false);

      _this.closeCallbacks.add(callback);
    });

    _this.closeCallbacks = new EventPool();
    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Modal, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps, nextState) {
      return !(this.state.open === nextState.open && nextState.open === false);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.updateBodyState(this.state.open, false);

      if (this.state.open) {
        this.renderIntoDocument();
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      this.updateBodyState(this.state.open, prevState.open);

      if (this.state.open) {
        this.renderIntoDocument();
      } else {
        prevState.open && this.toggleModal.close();
        var modalContent = this.context.modalContent;

        if (modalContent) {
          modalContent.goForward();
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.containerNode) {
        ReactDOM.unmountComponentAtNode(this.containerNode);
        document.body.removeChild(this.containerNode); // TODO 代码和updateBodyState重复，后期优化，有状态组件产生了副作用

        var body = document.body;
        var bodyPaddingRight = parseInt(body.style.paddingRight, 10) || 0;

        var _scrollbarWidth = body.scrollHeight > window.innerHeight ? scrollbarWidth : 0;

        classlist(body).remove("".concat("waui", "-modal_open"));

        if (bodyPaddingRight) {
          body.style.paddingRight = bodyPaddingRight - _scrollbarWidth + 'px';
        } else {
          body.style.paddingRight = '';
        }
      }
    }
  }, {
    key: "updateBodyState",
    value: function updateBodyState(open, prevOpen) {
      if (this.context.modalContent) {
        return;
      }

      var body = document.body;
      var bodyPaddingRight = parseInt(body.style.paddingRight, 10) || 0;

      var _scrollbarWidth = body.scrollHeight > window.innerHeight ? scrollbarWidth : 0;

      if (open && !prevOpen) {
        classlist(body).add("".concat("waui", "-modal_open"));
        body.style.paddingRight = bodyPaddingRight + _scrollbarWidth + 'px';
      } else if (!open && prevOpen) {
        this.closeCallbacks.add(function () {
          classlist(body).remove("".concat("waui", "-modal_open"));

          if (bodyPaddingRight) {
            body.style.paddingRight = bodyPaddingRight - _scrollbarWidth + 'px';
          } else {
            body.style.paddingRight = '';
          }
        });
      }
    }
    /**
     * @public
     * @name this.refs.modal.open
     * @description 打开模态框
     */

  }, {
    key: "open",
    value: function open() {
      this.setState({
        open: true
      });
      this.props.onToggle && this.props.onToggle(true);
    }
    /**
     * @public
     * @name this.refs.modal.close
     * @param {function} [callback] 关闭后的回调，动画结束后执行
     * @description 关闭模态框
     */

  }, {
    key: "renderIntoDocument",
    value: function renderIntoDocument() {
      var _this2 = this;

      if (!this.containerNode) {
        this.containerNode = document.createElement('div');
        document.body.appendChild(this.containerNode);
      }

      var onRendered = function onRendered() {
        if (!_this2.toggleModal) {
          var node = ReactDOM.findDOMNode(_this2.content);
          _this2.toggleModal = new ToggleNode(node, "".concat("waui", "-modal_open"));

          _this2.toggleModal.onClose = function () {
            return _this2.closeCallbacks.free();
          };
        }

        _this2.toggleModal.open();

        var modalContent = _this2.context.modalContent;

        if (modalContent) {
          modalContent.backUp();
        }
      };

      this.renderIntoDocument = function () {
        var _this2$props = _this2.props,
            open = _this2$props.open,
            onToggle = _this2$props.onToggle,
            onClose = _this2$props.onClose,
            other = _objectWithoutProperties(_this2$props, ["open", "onToggle", "onClose"]);

        ReactDOM.render(React.createElement(ModalContent, _extends({
          ref: function ref(content) {
            return _this2.content = content;
          },
          close: _this2.close,
          modal: _this2
        }, other)), _this2.containerNode, onRendered);
      };

      this.renderIntoDocument();
    }
  }, {
    key: "render",
    value: function render() {
      return null;
    }
  }]);

  return Modal;
}(Component);

Modal.contextTypes = {
  modalContent: PropTypes.object
};
Modal.propTypes = {
  /** 是否打开 */
  open: PropTypes.bool,

  /** 切换 open 状态后的回调，参数为切换后的 open 状态，立刻执行，不会等到动画结束后 */
  onToggle: PropTypes.func,

  /** 是否锁定，锁定后点击背景无法关闭 */
  lock: PropTypes.bool,

  /** 关闭后的回调，动画结束后执行。如果 close 方法传入回调，则此属性不会触发 */
  onClose: PropTypes.func,

  /** 尺寸，可选值：`sm`, `lg`, 默认中等尺寸 */
  size: PropTypes.oneOf(['sm', 'lg'])
};
export default Modal;

==> core-react-0.8.2.tgz: package/es/Modal/Modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import classlist from 'classlist';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import EventPool from '../_utils/EventPool';
import ToggleNode from '../_utils/ToggleNode';
import ModalContent from './ModalContent';

var scrollbarWidth = function () {
  var scrollDiv = document.createElement('div');
  var body = document.body;
  scrollDiv.className = "".concat("waui", "-modal__scrollbar-measure");
  body.appendChild(scrollDiv);
  var scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
  body.removeChild(scrollDiv);
  return scrollbarWidth;
}();

var Modal = /*#__PURE__*/function (_Component) {
  _inherits(Modal, _Component);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Modal).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _this.props.onClose;

      _this.setState({
        open: false
      });

      _this.props.onToggle && _this.props.onToggle(false);

      _this.closeCallbacks.add(callback);
    });

    _this.closeCallbacks = new EventPool();
    _this.state = {
      open: props.open || false
    };
    return _this;
  }

  _createClass(Modal, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'open' in nextProps && this.setState({
        open: nextProps.open
      });
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps, nextState) {
      return !(this.state.open === nextState.open && nextState.open === false);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.updateBodyState(this.state.open, false);

      if (this.state.open) {
        this.renderIntoDocument();
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      this.updateBodyState(this.state.open, prevState.open);

      if (this.state.open) {
        this.renderIntoDocument();
      } else {
        prevState.open && this.toggleModal.close();
        var modalContent = this.context.modalContent;

        if (modalContent) {
          modalContent.goForward();
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.containerNode) {
        ReactDOM.unmountComponentAtNode(this.containerNode);
        document.body.removeChild(this.containerNode); // TODO 代码和updateBodyState重复，后期优化，有状态组件产生了副作用

        var body = document.body;
        var bodyPaddingRight = parseInt(body.style.paddingRight, 10) || 0;

        var _scrollbarWidth = body.scrollHeight > window.innerHeight ? scrollbarWidth : 0;

        classlist(body).remove("".concat("waui", "-modal_open"));

        if (bodyPaddingRight) {
          body.style.paddingRight = bodyPaddingRight - _scrollbarWidth + 'px';
        } else {
          body.style.paddingRight = '';
        }
      }
    }
  }, {
    key: "updateBodyState",
    value: function updateBodyState(open, prevOpen) {
      if (this.context.modalContent) {
        return;
      }

      var body = document.body;
      var bodyPaddingRight = parseInt(body.style.paddingRight, 10) || 0;

      var _scrollbarWidth = body.scrollHeight > window.innerHeight ? scrollbarWidth : 0;

      if (open && !prevOpen) {
        classlist(body).add("".concat("waui", "-modal_open"));
        body.style.paddingRight = bodyPaddingRight + _scrollbarWidth + 'px';
      } else if (!open && prevOpen) {
        this.closeCallbacks.add(function () {
          classlist(body).remove("".concat("waui", "-modal_open"));

          if (bodyPaddingRight) {
            body.style.paddingRight = bodyPaddingRight - _scrollbarWidth + 'px';
          } else {
            body.style.paddingRight = '';
          }
        });
      }
    }
    /**
     * @public
     * @name this.refs.modal.open
     * @description 打开模态框
     */

  }, {
    key: "open",
    value: function open() {
      this.setState({
        open: true
      });
      this.props.onToggle && this.props.onToggle(true);
    }
    /**
     * @public
     * @name this.refs.modal.close
     * @param {function} [callback] 关闭后的回调，动画结束后执行
     * @description 关闭模态框
     */

  }, {
    key: "renderIntoDocument",
    value: function renderIntoDocument() {
      var _this2 = this;

      if (!this.containerNode) {
        this.containerNode = document.createElement('div');
        document.body.appendChild(this.containerNode);
      }

      var onRendered = function onRendered() {
        if (!_this2.toggleModal) {
          var node = ReactDOM.findDOMNode(_this2.content);
          _this2.toggleModal = new ToggleNode(node, "".concat("waui", "-modal_open"));

          _this2.toggleModal.onClose = function () {
            return _this2.closeCallbacks.free();
          };
        }

        _this2.toggleModal.open();

        var modalContent = _this2.context.modalContent;

        if (modalContent) {
          modalContent.backUp();
        }
      };

      this.renderIntoDocument = function () {
        var _this2$props = _this2.props,
            open = _this2$props.open,
            onToggle = _this2$props.onToggle,
            onClose = _this2$props.onClose,
            other = _objectWithoutProperties(_this2$props, ["open", "onToggle", "onClose"]);

        ReactDOM.render( /*#__PURE__*/React.createElement(ModalContent, _extends({
          ref: function ref(content) {
            return _this2.content = content;
          },
          close: _this2.close,
          modal: _this2
        }, other)), _this2.containerNode, onRendered);
      };

      this.renderIntoDocument();
    }
  }, {
    key: "render",
    value: function render() {
      return null;
    }
  }]);

  return Modal;
}(Component);

Modal.contextTypes = {
  modalContent: PropTypes.object
};
Modal.propTypes = {
  /** 是否打开 */
  open: PropTypes.bool,

  /** 切换 open 状态后的回调，参数为切换后的 open 状态，立刻执行，不会等到动画结束后 */
  onToggle: PropTypes.func,

  /** 是否锁定，锁定后点击背景无法关闭 */
  lock: PropTypes.bool,

  /** 关闭后的回调，动画结束后执行。如果 close 方法传入回调，则此属性不会触发 */
  onClose: PropTypes.func,

  /** 尺寸，可选值：`sm`, `lg`, 默认中等尺寸 */
  size: PropTypes.oneOf(['sm', 'lg'])
};
export default Modal;
